# PyTorch RDC-Net

This is a PyTorch implementation of the [RDC-Net](https://github.com/fmi-basel/RDCNet) for instance segmentation of 2D and 3D images. Some demo training scripts can be found [here](https://github.com/fmi-faim/faim_rdcnet).


## Citation
If you find this work useful, please consider citing:

```bibtex
@inproceedings{ortiz2020,
  title={RDCNet: Instance segmentation with a minimalist recurrent residual network},
  author={Ortiz, Raphael and de Medeiros, Gustavo and Peters H.F.M., Antoine and Liberali, Prisca and Rempfler, Markus},
  booktitle={International Workshop on Machine Learning in Medical Imaging},
  year={2020},
}
```
